@@ -21,11 +21,13 @@ from Bio._py3k import urlopen as _urlopen
 from Bio._py3k import _binary_to_string_handle
 
 
-def get_prodoc_entry(id,
-                     cgi='https://prosite.expasy.org/cgi-bin/prosite/get-prodoc-entry'):
+def get_prodoc_entry(
+    id, cgi="https://prosite.expasy.org/cgi-bin/prosite/get-prodoc-entry"
+):
     """Get a text handle to a PRODOC entry at ExPASy in HTML format.
 
     >>> from Bio import ExPASy
+    >>> import os
     >>> in_handle = ExPASy.get_prodoc_entry('PDOC00001')
     >>> html = in_handle.read()
     >>> in_handle.close()
@@ -34,6 +36,7 @@ def get_prodoc_entry(id,
     ...     # Python2/3 docstring workaround: Revise for 'Python 3 only'
     ...     _ = out_handle.write(html)
     ...
+    >>> os.remove("myprodocrecord.html")  # tidy up
 
     For a non-existing key XXX, ExPASy returns an HTML-formatted page
     containing this text: 'There is currently no PROSITE entry for'
@@ -41,11 +44,13 @@ def get_prodoc_entry(id,
     return _binary_to_string_handle(_urlopen("%s?%s" % (cgi, id)))
 
 
-def get_prosite_entry(id,
-                      cgi='https://prosite.expasy.org/cgi-bin/prosite/get-prosite-entry'):
+def get_prosite_entry(
+    id, cgi="https://prosite.expasy.org/cgi-bin/prosite/get-prosite-entry"
+):
     """Get a text handle to a PROSITE entry at ExPASy in HTML format.
 
     >>> from Bio import ExPASy
+    >>> import os
     >>> in_handle = ExPASy.get_prosite_entry('PS00001')
     >>> html = in_handle.read()
     >>> in_handle.close()
@@ -54,6 +59,7 @@ def get_prosite_entry(id,
     ...     # Python 2/3 docstring workaround: Revise for 'Python 3 only'
     ...     _ = out_handle.write(html)
     ...
+    >>> os.remove("myprositerecord.html")  # tidy up
 
     For a non-existing key XXX, ExPASy returns an HTML-formatted page
     containing this text: 'There is currently no PROSITE entry for'
