@@ -23,46 +23,46 @@ class EnzymeTests(unittest.TestCase):
         self.assertEqual(len(records), 8)
         self.assertEqual(records[0].entry, "1.1.1.1")
         self.assertEqual(records[0].name,
-                         ['alcohol dehydrogenase',
-                          'aldehyde reductase',
-                          'ADH',
-                          'alcohol dehydrogenase (NAD)',
-                          'aliphatic alcohol dehydrogenase',
-                          'ethanol dehydrogenase',
-                          'NAD-dependent alcohol dehydrogenase',
-                          'NAD-specific aromatic alcohol dehydrogenase',
-                          'NADH-alcohol dehydrogenase',
-                          'NADH-aldehyde dehydrogenase',
-                          'primary alcohol dehydrogenase',
-                          'yeast alcohol dehydrogenase'])
+                         ["alcohol dehydrogenase",
+                          "aldehyde reductase",
+                          "ADH",
+                          "alcohol dehydrogenase (NAD)",
+                          "aliphatic alcohol dehydrogenase",
+                          "ethanol dehydrogenase",
+                          "NAD-dependent alcohol dehydrogenase",
+                          "NAD-specific aromatic alcohol dehydrogenase",
+                          "NADH-alcohol dehydrogenase",
+                          "NADH-aldehyde dehydrogenase",
+                          "primary alcohol dehydrogenase",
+                          "yeast alcohol dehydrogenase"])
         self.assertEqual(records[0].pathway,
-                         [('PATH', 'ec00010', 'Glycolysis / Gluconeogenesis'),
-                          ('PATH', 'ec00071', 'Fatty acid degradation'),
-                          ('PATH', 'ec00260', 'Glycine, serine and threonine metabolism'),
-                          ('PATH', 'ec00350', 'Tyrosine metabolism'),
-                          ('PATH', 'ec00592', 'alpha-Linolenic acid metabolism'),
-                          ('PATH', 'ec00625', 'Chloroalkane and chloroalkene degradation'),
-                          ('PATH', 'ec00626', 'Naphthalene degradation'),
-                          ('PATH', 'ec00830', 'Retinol metabolism'),
-                          ('PATH', 'ec00980', 'Metabolism of xenobiotics by cytochrome P450'),
-                          ('PATH', 'ec00982', 'Drug metabolism - cytochrome P450'),
-                          ('PATH', 'ec01100', 'Metabolic pathways'),
-                          ('PATH', 'ec01110', 'Biosynthesis of secondary metabolites'),
-                          ('PATH', 'ec01120', 'Microbial metabolism in diverse environments'),
-                          ('PATH', 'ec01130', 'Biosynthesis of antibiotics')])
+                         [("PATH", "ec00010", "Glycolysis / Gluconeogenesis"),
+                          ("PATH", "ec00071", "Fatty acid degradation"),
+                          ("PATH", "ec00260", "Glycine, serine and threonine metabolism"),
+                          ("PATH", "ec00350", "Tyrosine metabolism"),
+                          ("PATH", "ec00592", "alpha-Linolenic acid metabolism"),
+                          ("PATH", "ec00625", "Chloroalkane and chloroalkene degradation"),
+                          ("PATH", "ec00626", "Naphthalene degradation"),
+                          ("PATH", "ec00830", "Retinol metabolism"),
+                          ("PATH", "ec00980", "Metabolism of xenobiotics by cytochrome P450"),
+                          ("PATH", "ec00982", "Drug metabolism - cytochrome P450"),
+                          ("PATH", "ec01100", "Metabolic pathways"),
+                          ("PATH", "ec01110", "Biosynthesis of secondary metabolites"),
+                          ("PATH", "ec01120", "Microbial metabolism in diverse environments"),
+                          ("PATH", "ec01130", "Biosynthesis of antibiotics")])
         self.assertEqual(records[0].dblinks,
-                         [('ExplorEnz - The Enzyme Database', ['1.1.1.1']),
-                          ('IUBMB Enzyme Nomenclature', ['1.1.1.1']),
-                          ('ExPASy - ENZYME nomenclature database', ['1.1.1.1']),
-                          ('UM-BBD (Biocatalysis/Biodegradation Database)', ['1.1.1.1']),
-                          ('BRENDA, the Enzyme Database', ['1.1.1.1']),
-                          ('CAS', ['9031-72-5'])])
+                         [("ExplorEnz - The Enzyme Database", ["1.1.1.1"]),
+                          ("IUBMB Enzyme Nomenclature", ["1.1.1.1"]),
+                          ("ExPASy - ENZYME nomenclature database", ["1.1.1.1"]),
+                          ("UM-BBD (Biocatalysis/Biodegradation Database)", ["1.1.1.1"]),
+                          ("BRENDA, the Enzyme Database", ["1.1.1.1"]),
+                          ("CAS", ["9031-72-5"])])
         self.assertEqual(records[-1].entry, "2.7.2.1")
         self.assertEqual(str(records[-1]).replace(" ", "").split("\n")[:10],
-                         ['ENTRYEC2.7.2.1', 'NAMEacetatekinase', 'acetokinase',
-                          'AckA', 'AK', 'acetickinase', 'acetatekinase(phosphorylating)',
-                          'CLASSTransferases;', 'Transferringphosphorus-containinggroups;',
-                          'Phosphotransferaseswithacarboxygroupasacceptor'])
+                         ["ENTRYEC2.7.2.1", "NAMEacetatekinase", "acetokinase",
+                          "AckA", "AK", "acetickinase", "acetatekinase(phosphorylating)",
+                          "CLASSTransferases;", "Transferringphosphorus-containinggroups;",
+                          "Phosphotransferaseswithacarboxygroupasacceptor"])
 
     def test_irregular(self):
         with open("KEGG/enzyme.irregular") as handle:
@@ -83,9 +83,9 @@ class EnzymeTests(unittest.TestCase):
             self.assertEqual(len(records), 1)
         self.assertEqual(records[0].entry, "5.4.2.2")
         self.assertEqual(records[0].genes[0],
-                         ('HSA', ['5236', '55276']))
+                         ("HSA", ["5236", "55276"]))
         self.assertEqual(records[0].genes[8],
-                         ('CSAB', ['103224690', '103246223']))
+                         ("CSAB", ["103224690", "103246223"]))
 
     def test_exceptions(self):
         with open("KEGG/enzyme.sample") as handle:
@@ -109,18 +109,18 @@ class CompoundTests(unittest.TestCase):
         self.assertEqual(records[1].mass, "")  # Why?
         self.assertEqual(records[1].formula, "C2H4NO2R(C2H2NOR)n")
         self.assertEqual(records[1].name,
-                         ['Protein'])
+                         ["Protein"])
         self.assertEqual(records[1].pathway,
-                         [('PATH', 'map00450', 'Selenocompound metabolism')])
+                         [("PATH", "map00450", "Selenocompound metabolism")])
         self.assertEqual(len(records[1].enzyme), 21)
-        self.assertEqual(records[1].enzyme[0], ('2.3.2.6'))
+        self.assertEqual(records[1].enzyme[0], ("2.3.2.6"))
         self.assertEqual(records[1].structures, [])
-        self.assertEqual(records[1].dblinks[0], ('PubChem', ['3319']))
+        self.assertEqual(records[1].dblinks[0], ("PubChem", ["3319"]))
         self.assertEqual(str(records[-1]).replace(" ", "").split("\n")[:10],
-                         ['ENTRYC01386', 'NAMENH2Mec', '7-Amino-4-methylcoumarin',
-                          'FORMULAC10H9NO2', 'DBLINKSCAS:26093-31-2',
-                          'PubChem:4580', 'ChEBI:51771', 'ChEMBL:CHEMBL270672',
-                          'KNApSAcK:C00048593', 'PDB-CCD:MCM'])
+                         ["ENTRYC01386", "NAMENH2Mec", "7-Amino-4-methylcoumarin",
+                          "FORMULAC10H9NO2", "DBLINKSCAS:26093-31-2",
+                          "PubChem:4580", "ChEBI:51771", "ChEMBL:CHEMBL270672",
+                          "KNApSAcK:C00048593", "PDB-CCD:MCM"])
 
     def test_irregular(self):
         with open("KEGG/compound.irregular") as handle:
